@@ -1,9 +1,9 @@
 use v6;
 use fatal;
 
-unit class Getopt::Long:ver<0.1.7>;
+unit class Getopt::Long:ver<0.1.8>;
 
-role Exceptional is CORE::Exception {
+role Exceptional is Exception {
 }
 
 class Exception does Exceptional {
@@ -484,7 +484,7 @@ method get-options(Getopt::Long:D: @args is copy, :%hash, :named-anywhere(:$perm
 		}
 	}
 	@$write-args = @list if $write-args;
-	state Str @labels = flat <first second third fourth fifth sixth seventh eighth nineth tenth some> ... *;
+	state Str @labels = flat <first second third fourth fifth sixth seventh eighth nineth tenth some some> ... *;
 	my &fallback-converter = $compat-positional ?? &maybe-converter !! &null-converter;
 	my @converters = |@!positionals, &fallback-converter, *;
 	@list = (@labels Z @list Z @converters).map: { wrap-exceptions(|@^args) }
